






#输入df和希望呈现的数字格式（'{:,}'、'{:.2%}'、'{:,.0f}'），呈现带格式的表格
def func_format_display(df, num_fmt):
    all_props = [
        ('border','2px solid black'),
    ]
    th_props = [
        ('font-size', '11px'),
        ('text-align', 'center'),
        ('font-weight', 'bold'),
        ('color', 'black'),               ## #6d6d6d
        ('background-color', 'white'),    ## #f7f7f9
        ('border','1px dashed black')
    ]
    td_props = [
        ('font-size', '9px'),
        ('text-align', 'right'),
        ('color', 'black'),
        ('background-color', 'white'),    ## #f7f7f9
        ('border','1px dashed black')
    ]

    config_fmt = [{'selector':'','props':all_props}, 
                  {'selector':'th','props':th_props},
                  {'selector':'td','props':td_props}
                 ]
    dict_fmt = {}
    lst_barfmt = []
    for k in df.columns:
        dict_fmt[k] = num_fmt   #'{:,}' #'{:.2%}' #'{:,.0f}'
        lst_barfmt.append(k)
    display(df.style.set_table_styles(config_fmt).format(dict_fmt).bar(subset = lst_barfmt, width = 80, align = 'mid'))










from setuptools import setup, find_packages

VERSION = '0.0.2' 
DESCRIPTION = 'python package of frequently used functions'
LONG_DESCRIPTION = 'python package of frequently used functions'

# Setting up
setup(
       # the name must match the folder name 'funcsfreq'
        name="funcsfrequse",
        version=VERSION,
        author="y",
        author_email="<y@outlook.com>",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=[], # add any additional packages that 
        # needs to be installed along with your package. Eg: 'caer'
        setup_requires=['wheel'],
        keywords=['python', 'first package'],
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Other Audience",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
        ]

)







########################### 连接ODPS ###########################

import json
from odps import ODPS


def func_conn_odps(fpath_cfg):
    #连接odps的配置信息
    with open(fpath_cfg, 'r') as c:
        dict_conn_odps = json.load(c)
    v_accessid = dict_conn_odps['access_id']
    v_accesskey = dict_conn_odps['access_key']
    v_project = dict_conn_odps['project']
    v_endpoint = dict_conn_odps['endpoint']
    odps = ODPS(v_accessid, v_accesskey, v_project, endpoint = v_endpoint)
    return odps

########################### ###########################


#设置全局参数
from odps import options
options.sql.settings = {"odps.sql.submit.mode" : "script"}




########################### 构建函数 ###########################

from odps.df import DataFrame
import time


def func_run_sql(fpath_cfg, str_sql, flag_mute = 0, mode = None):
    odps = func_conn_odps(fpath_cfg)
    #异步的方式执行
    instance = odps.run_sql(str_sql)
    if flag_mute == 0:
        print(instance.get_logview_address())
    else:
        pass
    if mode == 'parallel':
        pass
    else:
        t1 = time.time()
        instance.wait_for_success()  #调用 wait_for_completion 方法会阻塞直到instance执行完成，wait_for_success 方法同样会阻塞，不同的是， 如果最终任务执行失败，则会抛出相关异常。
        t2 = time.time()
        if flag_mute == 0:
            print('cost {} seconds'.format(str(round(t2 - t1))))
        else:
            pass

def func_get_schema(fpath_cfg, nm_table):
    odps = func_conn_odps(fpath_cfg)
    t = odps.get_table(nm_table)
    print(t.schema, str(round(t.size/1024/1024, 6)) + ' MB')
    return(t.size)


def func_downloaddata(fpath_cfg, nm_table, flag_mute = 0):
    odps = func_conn_odps(fpath_cfg)
    t = odps.get_table(nm_table)
    if flag_mute == 0:
        print(t.schema, str(round(t.size/1024/1024, 3)) + ' MB')
    else:
        pass
    #convert data to df
    df_odps = DataFrame(t)
    df = df_odps.to_pandas()
    return(df)


#输入sql代码 和 临时表名，返回dataframe
def func_run_sql_get_result(fpath_cfg, str_sql, nm_table, flag_mute, mode):
    odps = func_conn_odps(fpath_cfg)
    func_run_sql(str_sql, flag_mute, mode)
    df_r = func_downloaddata(nm_table, flag_mute)
    return df_r

########################### ###########################


